/*
 * ElementTable.java
 *
 * Created on February 17, 2002, 9:40 AM
 */

/**
 *
 * @author  Chris Schmidt
 */

import java.util.*;
import org.xml.sax.*;

/** Class designed to hold all information of the Element Table
 */
public class ElementTable {
    // Class variables
    /** Vector where the final table information will reside, in order */
    private Vector finalTbl;
    
    /** Creates a new instance of ElementTable */
    public ElementTable() {
        finalTbl = new Vector();        
    }
    
    /** Add a single element row for later presentation to the user
     * @param elementName Name of the element
     * @param pathIndex Index to the pre-generated path
     * @param startLoc Starting index location of the element being added */    
    public void addElement(String elementName, int pathIndex, int startLoc) {
        // This is a new element, add it (and it's information) into the temp 
        // vector
        ElementTableData tempData = new ElementTableData();
        
        tempData.setElementName(elementName);
        tempData.setElementIndex(pathIndex);
        tempData.setElementStart(startLoc);
        
        finalTbl.add(tempData);
    }
    
    /** Finalize an element's information
     * @param elementName Needed to match to a unique element in the XML document
     * @param pathIndex Needed to uniquely match the element
     * @param endLoc Ending location of the element being updated
     */    
    public void finishElement(String elementName, int pathIndex, int endLoc) {
        // Find the element in the vector and update it's ending
        // location information
        ElementTableData tempData;
        ElementTableData finishedElement = null;
        
        for (Enumeration e = finalTbl.elements(); e.hasMoreElements();) {
            tempData = (ElementTableData)e.nextElement();
            
            if (tempData.getElementName().equals(elementName) && 
                tempData.getElementIndex() == pathIndex) {
                    // Found an element that matches
                    // Note that there may be multiple
                    // matches in the vector...
                    finishedElement = tempData;
            }
        }
        
        // The last element in the vector found is the one that should be
        // completed (if the XML is valid)
        if (finishedElement != null) {
            finishedElement.setElementEnd(endLoc);            
        }             
    }
    
    /** Returns the enumeration of all elements captured to that point
     * @return Enumeration Returns the enumeration of all elements stored thus far
     */    
    public Enumeration getElements() {
        // Returns the finished element vector as an Enumeration
        return finalTbl.elements();
    }
    
}
